/* Arduino Si4703 Library
 * Written by Ryan Owens for SparkFun Electronics
 * 7/1/11
 *
 * This library is for use with the SparkFun Si4703 Breakout Board
 * Released under the 'Buy Me a Beer' license
 * (If we ever meet, you buy me a beer)
 *
 * See the example sketches to learn how to use the library in your code.
*/

#ifndef Si4703_h
#define Si4703_h

#include "WProgram.h"

//Assign the radio pin numbers
#define	RADIO_RESET_PIN	2
#define INT_PIN	3

//Define the I2C Pin Numbers
#define SDIO	A4
#define SCKL	A5

#define ON	true
#define OFF	false

#define FAIL  false
#define SUCCESS  true

#define UP	true
#define DOWN	false

class Si4703
{
	public:
		//This is just a constructor.
		Si4703();
		/*
		* Description: 
		*	Initializes the Si4703 for proper operation.
		*/
		void begin(void);
		/*
		* Description: 
		*	Used to to tune the radio to a desired frequency. The library uses the mode indicated in the
		* 	begin() function to determine how to set the frequency.
		* Parameters:
		*	frequency - The frequency to tune to, in kHz (or in 10kHz if using FM mode).
		* Returns:
		*	True
		* TODO:
		* 	Make the function return true if the tune was successful, else return false.
		*/
		void tuneFrequency(int newChannel);
		/*
		* Description:
		*	This function currently does not work!
		* TODO:
		*	Make this function work.
		*/
		int getFrequency(void);
		/*
		* Description:
		*	Seeks up or down to the next valid channel.
		* Parameters:
		*	direction - The direction that the radio will search for a new channel (UP or DOWN are valid parameters)
		* Returns:
		*	True is a valid channel was found, otherwise false
		*/
		bool seek(bool seekDirection);
		/*
		* Description:
		*	Increases or decreases the current volume
		* Parameters:
		*	setting - Determines is volume will be increased or decreased (UP or DOWN are valid parameters)
		*/
		void volume(bool setting);
		/*
		* Description:
		*	Toggles the mute setting
		*/
		void toggleMute(void);
		
	private:
		/*
		* A local copy of the register settings of the si4703
		*/
		uint16_t si4703_registers[16]; //There are 16 registers, each 16 bits large
		/*
		* Send the register values in the local copy to the si4703
		*/
		bool updateRegisters(void);
		/*
		* Copy the register values in the si4703 to the local array
		*/
		void readRegisters(void);
		
};

#endif
