/*
* Si4703 Example Sketch
* Written by Ryan Owens for SparkFun Electronics
*
* This example sketch illustrates how to use some of the basic commands in the
* Si4703 Library. The user can use a serial terminal to send characters (which correspond to basic commands)
* to the radio. The serial interface is set at 9600 bps.
*
* HARDWARE SETUP:
* Arduino : Si470x board
* 3.3V : VCC
* GND : GND
* A5 : SCLK
* A4 : SDIO
* D2 : RST
* The shield should be plugged into an Arduino Pro 3.3V (or other 3.3V Arduino board.
*
* USING THE SKETCH:
* Once you've connected the Si4703 into your Arduino board, connect the Arduino to your computer
* and select the corresponding board and COM port from the Tools menu and upload the sketch. After
* the sketch has been updated, open the serial terminal using a 9600 bps baud speed. The sketch accepts
* single character commands (just enter the character and press 'send'). Here is a list of the acceptable commands:
* 8 - Increase the volume
* 2 - Decrease the volume
* 4 - Seek down to the next channel
* 6 - Seek up to the next channel
* m - Toggle the mute
*
*/

//Add the Si4703 Library to the sketch.
#include <Si4703.h>
#include <Wire.h>

//Create an instance of the Si4735 named radio.
Si4703 radio;

void setup()
{
  //Create a serial connection
  Serial.begin(9600);

  //Initialize the radio to the FM mode (Possible modes are AM, FM, SW, LW).
  //The mode will set the proper bandwidth. Ensure that the antenna
  //switch on the shield is configured for the desired mode.
  radio.begin();
  
  //Set the FM Frequency to 97.3 MHz
  radio.tuneFrequency(973);
}

void loop()
{       
  //Wait until a character comes in on the Serial port.
  if(Serial.available()>0){
    //Decide what to do based on the character received.
    switch(Serial.read()){
      //If we get the number 8, turn the volume up.
      case '8':radio.volume(UP);
        break;
      //If we get the number 2, turn the volume down.
      case '2':radio.volume(DOWN);
        break;
      //If we get the number 4, seek down to the next channel in the current bandwidth (wrap to the top when the bottom is reached).
      case '4':radio.seek(DOWN);
        break;
      //If we get the number 6, seek up to the next channel in the current bandwidth (wrap to the bottom when the top is reached).
      case '6':radio.seek(UP);
        break;
      //If we get the letter m, mute the radio.
      case 'M':
      case 'm':radio.toggleMute();
        break;
      default:
        break;
    }
  }   
}

